#[non_exhaustive]pub enum EncodeBackendPreference {
Auto,
CpuOnly,
PreferDevice,
RequireDevice,
}Expand description
Runtime preference for JPEG 2000 Lossless encode backends.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Let the crate choose the safest measured backend for the request.
CpuOnly
Always use CPU encoding.
PreferDevice
Prefer a device backend, but fall back to CPU when unavailable.
RequireDevice
Require a device backend and fail when it cannot be used.