pub struct ExportWorkflowError { /* private fields */ }Expand description
Structured error preserving the application stage and underlying library error.
Implementations
Sourceimpl ExportWorkflowError
impl ExportWorkflowError
Sourcepub const fn stage(&self) -> ExportWorkflowStage
pub const fn stage(&self) -> ExportWorkflowStage
Return the stage that failed.
Sourcepub const fn source_error(&self) -> &Error
pub const fn source_error(&self) -> &Error
Return the structured library error that caused the failure.