#[non_exhaustive]pub struct RouteCorpusCoverageReport {
pub source_root: PathBuf,
pub transfer_syntax_uid: Option<&'static str>,
pub transfer_syntax_uids: Vec<&'static str>,
pub requested_frames_per_level: u64,
pub max_levels: Option<u32>,
pub sources_considered: usize,
pub available_frames: u64,
pub complete_frame_coverage: bool,
pub reports: Vec<RouteCoverageReport>,
pub failures: Vec<RouteCorpusCoverageFailure>,
pub metrics: ExportMetrics,
pub elapsed_micros: u128,
}Expand description
Route coverage report for a source corpus.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_root: PathBufRoot directory scanned for source slides.
transfer_syntax_uid: Option<&'static str>Common transfer syntax UID used by all successful reports, when one exists.
transfer_syntax_uids: Vec<&'static str>Unique transfer syntax UIDs used by successful per-source reports.
requested_frames_per_level: u64Requested frame sample count per level.
max_levels: Option<u32>Optional cap on levels inspected per source.
sources_considered: usizeNumber of source files considered.
available_frames: u64Total frames available across successful reports.
complete_frame_coverage: boolWhether every available frame in successful reports was sampled.
reports: Vec<RouteCoverageReport>Successful per-source reports.
failures: Vec<RouteCorpusCoverageFailure>Per-source failures that did not stop corpus aggregation.
metrics: ExportMetricsAggregate metrics across successful reports.
elapsed_micros: u128Wall-clock elapsed time in microseconds.