RouteCounters

Struct RouteCounters 

#[non_exhaustive]
pub struct RouteCounters {
Show 38 fields pub total_frames: u64, pub cpu_input_frames: u64, pub gpu_input_decode_frames: u64, pub gpu_encode_frames: u64, pub gpu_validation_frames: u64, pub gray_frames: u64, pub rgb_like_frames: u64, pub other_component_frames: u64, pub unknown_pixel_profile_frames: u64, pub bits8_frames: u64, pub bits16_frames: u64, pub other_bit_depth_frames: u64, pub gpu_transcode_frames: u64, pub resident_gpu_transcode_frames: u64, pub partial_gpu_transcode_frames: u64, pub gpu_input_decode_batches: u64, pub gpu_compose_batches: u64, pub gpu_encode_batches: u64, pub auto_route_probe_frames: u64, pub auto_route_probe_gpu_batches: u64, pub auto_route_probe_cpu_micros: u128, pub auto_route_probe_gpu_micros: u128, pub auto_route_probe_selected_gpu_input_frames: u64, pub cpu_fallback_frames: u64, pub jpeg_passthrough_frames: u64, pub j2k_passthrough_frames: u64, pub j2k_direct_htj2k_frames: u64, pub jpeg_retile_frames: u64, pub jpeg_retile_rejected_frames: u64, pub jpeg_retile_source_unsupported_frames: u64, pub jpeg_retile_geometry_mismatch_frames: u64, pub jpeg_retile_profile_unsupported_frames: u64, pub jpeg_retile_mcu_invalid_frames: u64, pub jpeg_retile_us: u128, pub jpeg_retile_to_htj2k_53_frames: u64, pub jpeg_cpu_encode_frames: u64, pub jpeg_metal_encode_frames: u64, pub jpeg_decode_fallback_frames: u64,
}
Route, pixel-profile, and non-GPU-specific frame counters.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
total_frames: u64

Total frames handled by the report scope.

cpu_input_frames: u64

Frames whose source pixels were prepared on CPU.

gpu_input_decode_frames: u64

Frames decoded from source tiles on GPU.

gpu_encode_frames: u64

Frames encoded on GPU.

gpu_validation_frames: u64

Frames validated with GPU decode.

gray_frames: u64

Frames classified as grayscale.

rgb_like_frames: u64

Frames classified as RGB-like.

other_component_frames: u64

Frames with a component count other than gray or RGB-like.

unknown_pixel_profile_frames: u64

Frames whose pixel profile could not be classified.

bits8_frames: u64

Frames with 8-bit samples.

bits16_frames: u64

Frames with 16-bit samples.

other_bit_depth_frames: u64

Frames with another bit depth.

gpu_transcode_frames: u64

Frames using a GPU transcode route.

resident_gpu_transcode_frames: u64

Frames using a resident GPU transcode route.

partial_gpu_transcode_frames: u64

Frames using a mixed CPU/GPU transcode route.

gpu_input_decode_batches: u64

GPU input decode batch count.

gpu_compose_batches: u64

GPU composition batch count.

gpu_encode_batches: u64

GPU encode batch count.

auto_route_probe_frames: u64

Frames sampled by automatic route probes.

auto_route_probe_gpu_batches: u64

GPU batches dispatched by automatic route probes.

auto_route_probe_cpu_micros: u128

CPU-side automatic route probe time in microseconds.

auto_route_probe_gpu_micros: u128

GPU-side automatic route probe time in microseconds.

auto_route_probe_selected_gpu_input_frames: u64

Frames routed to GPU input because an automatic probe selected it.

cpu_fallback_frames: u64

Frames routed through CPU fallback.

jpeg_passthrough_frames: u64

Frames emitted by JPEG Baseline passthrough.

j2k_passthrough_frames: u64

Frames emitted by JPEG 2000 passthrough.

j2k_direct_htj2k_frames: u64

Frames emitted by direct J2K-to-HTJ2K recoding.

jpeg_retile_frames: u64

Frames re-tiled in the JPEG compressed domain.

jpeg_retile_rejected_frames: u64

Frames rejected from JPEG compressed-domain retiling.

jpeg_retile_source_unsupported_frames: u64

JPEG retile rejections because the source could not provide raw compressed tiles.

jpeg_retile_geometry_mismatch_frames: u64

JPEG retile rejections because raw tile geometry did not match the requested frame.

jpeg_retile_profile_unsupported_frames: u64

JPEG retile rejections because the JPEG pixel profile is unsupported for passthrough.

jpeg_retile_mcu_invalid_frames: u64

JPEG retile rejections because the source MCU/restart table was invalid.

jpeg_retile_us: u128

JPEG compressed-domain retiling time in microseconds.

jpeg_retile_to_htj2k_53_frames: u64

JPEG-retiled frames then transcoded through HTJ2K 5/3.

jpeg_cpu_encode_frames: u64

Frames encoded to JPEG on CPU.

jpeg_metal_encode_frames: u64

Frames encoded to JPEG on Metal.

jpeg_decode_fallback_frames: u64

Frames that required JPEG decode fallback.