#[non_exhaustive]pub struct RouteProfileRequest {
pub source_path: PathBuf,
pub options: ExportOptions,
pub source_aware_transfer_syntax: bool,
pub level: u32,
pub max_frames: u64,
}Expand description
Request to profile frame routing for one level without writing DICOM.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_path: PathBufPath to the source slide readable by wsi-rs.
options: ExportOptionsExport options used for route planning.
source_aware_transfer_syntax: boolWhether to resolve the transfer syntax from source compression before profiling.
level: u32Source pyramid level to profile.
max_frames: u64Maximum frames to sample.
Implementations
Sourceimpl RouteProfileRequest
impl RouteProfileRequest
Sourcepub fn new(
source_path: PathBuf,
options: ExportOptions,
level: u32,
max_frames: u64,
) -> Self
pub fn new( source_path: PathBuf, options: ExportOptions, level: u32, max_frames: u64, ) -> Self
Build a route profile request for one source level.
Sourcepub fn with_source_aware_transfer_syntax(self, source_aware: bool) -> Self
pub fn with_source_aware_transfer_syntax(self, source_aware: bool) -> Self
Set whether profiling should resolve transfer syntax from source compression.