#[non_exhaustive]pub struct ExportMetrics {
pub routes: RouteCounters,
pub jpeg_direct_htj2k: JpegDirectHtj2kMetrics,
pub gpu_encode: GpuEncodeMetrics,
pub timings: WriteTimings,
}Expand description
Export, routing, encode, validation, and writer counters.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.routes: RouteCountersRoute, pixel-profile, and non-GPU-specific frame counters.
jpeg_direct_htj2k: JpegDirectHtj2kMetricsDirect JPEG-to-HTJ2K coefficient-transcode counters and timings.
gpu_encode: GpuEncodeMetricsGPU JPEG 2000 encode configuration, counters, and stage timings.
timings: WriteTimingsProcessing and writer timing metrics.
Implementations
Sourceimpl ExportMetrics
impl ExportMetrics
Sourcepub const SERIALIZED_FIELD_COUNT: usize = 99
pub const SERIALIZED_FIELD_COUNT: usize = 99
Number of fields emitted by the public serialized metrics object.
Sourcepub fn route_passthrough_frames(&self) -> u64
pub fn route_passthrough_frames(&self) -> u64
Total frames emitted by compressed passthrough routes.
Sourcepub fn jpeg_retile_baseline_frames(&self) -> u64
pub fn jpeg_retile_baseline_frames(&self) -> u64
Frames emitted by JPEG compressed-domain retiling without HTJ2K transcode.
Sourcepub fn route_unclassified_frames(&self) -> u64
pub fn route_unclassified_frames(&self) -> u64
Frames not accounted for by a known route counter.
Sourcepub fn gpu_encode_effective_parallelism(&self) -> f64
pub fn gpu_encode_effective_parallelism(&self) -> f64
Ratio of summed GPU encode hardware time to observed GPU encode wall time.